@@ -164,6 +164,7 @@ color_replace_with_clipping();
 color_replace_no_clipping();
 
 blitting();
+blit_move();
 rotate();
 flipping();
 monochrome();
@@ -277,11 +278,7 @@ sub angle_lines {
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->angle_line({ 'x' => $center_x, 'y' => $center_y, 'radius' => ($center_y - $F->{'Y_CLIP'}), 'angle' => $angle, 'antialiased' => $aa });
-	if ($F->{'ACCELERATED'} && ! $aa) {
-	    $angle += .1;
-	} else {
 	    $angle += 1.1;
-	}
         $angle -= 360 if ($angle >= 360);
     } ## end while (time < $s)
 } ## end sub angle_lines
@@ -1288,16 +1285,34 @@ sub blitting {
     
     print_it($F, 'Testing Image blitting');
 
-    my $image = $SMALL_IMAGES[int(rand(scalar(@IMAGES)))];
-
     my $s = time + $factor;
     while (time < $s) {
+        my $image = $SMALL_IMAGES[int(rand(scalar(@IMAGES)))];
+
         $image->{'x'} = abs(rand($XX - $image->{'width'}));
         $image->{'y'} = $F->{'Y_CLIP'} + abs(rand(($YY - $F->{'Y_CLIP'}) - $image->{'height'}));
         $F->blit_write($image);
     }
 } ## end sub blitting
 
+sub blit_move {
+    
+    print_it($F, 'Testing Image blitting');
+
+    my $image = $SMALL_IMAGES[int(rand(scalar(@IMAGES)))];
+    $F->blit_write({%{$image},'x' => 0, 'y' => 0});
+    my $x = 0;
+    my $y = 0;
+    my $w = $image->{'width'};
+    my $h = $image->{'height'};
+    my $s = time + $factor;
+    while (time < $s) {
+        $F->blit_move({'x' => $x,'y' => $y,'width' => $w, 'height' => $h, 'x_dest' => $x + 6,'y_dest' => $y + 3});
+        $x += 6;
+        $y += 3;
+    }
+} ## end sub blit_move
+
 sub rotate {
     
     print_it($F, 'Scaling image for Rotate Test', 'FFFF00FF');
