@@ -15,8 +15,9 @@ use Time::HiRes qw(sleep time);
 use List::Util qw(shuffle);
 
 # use Data::Dumper::Simple;
-
-my $args = join('', @ARGV);
+my @a    = @ARGV;
+my $path = pop(@a);
+my $args = join('', @a);
 
 my $file = 0;
 $file = 1 if ($args =~ /file/i);
@@ -28,6 +29,8 @@ my $fullscreen = 0;
 $fullscreen = 1 if ($args =~ /full/i);
 
 my @fbs;
+
+# We show images on all devices
 foreach my $p (qw(/dev/graphics/fb /dev/fb)) {
     foreach my $b (0 .. 31) {
         push(@fbs, "$p$b") if (-e "$p$b");
@@ -64,7 +67,7 @@ foreach my $fb (@fbs) {
     );
 } ## end foreach my $fb (@fbs)
 
-gather($ARGV[-1]);
+gather($path);
 
 # print STDERR Dumper(\@pics);exit;
 
@@ -89,7 +92,8 @@ foreach my $F (@f) {
 while ($RUNNING) {
     sleep 1;
 }
-$f[0]->cls('ON');
+map { $_->cls('ON') } @f;
+
 foreach my $t (@thr) {
     $t->detach();
 }
@@ -126,7 +130,7 @@ sub show {
             $image = $FB->load_image(
                 {
                     'file'       => $name,
-                    'center'     => $FB->{'CENTER_XY'},
+                    'center'     => CENTER_XY,
                     'autolevels' => $auto
                 }
             );
@@ -136,7 +140,7 @@ sub show {
                     'width'      => $FB->{'XRES'},
                     'height'     => $FB->{'YRES'},
                     'file'       => $name,
-                    'center'     => $FB->{'CENTER_XY'},
+                    'center'     => CENTER_XY,
                     'autolevels' => $auto
                 }
             );
@@ -184,7 +188,7 @@ sub print_it {
                 'color'        => 'FFFFFFFF',
                 'text'         => $message,
                 'bounding_box' => 1,
-                'center'       => $fb->{'CENTER_X'},
+                'center'       => CENTER_X,
                 'antialias'    => 1
             }
         );
